@@ -21,6 +21,9 @@
 
 #define NO_ARGS		0
 #define ARGS		1
+#define PROMPT		2
+
+#define DEFAULT_PROMPT	"Enter filename"
 
 char *define_menu(struct menu **, char *, char *, int *);
 
