@@ -15,7 +15,7 @@ You should have received a copy of the GNU General Public License along with
 this program; if not, write to the Free Software Foundation, Inc., 675 Mass
 Ave, Cambridge, MA 02139, USA.
 
-please send patches or advice to: `shmit@meathook.intac.com'
+please send patches or advice to: `shmit@kublai.com'
 */
 #include <stdio.h>
 #include <stdlib.h>
