@@ -5,6 +5,7 @@
 
 #define MENU_BEGIN	"Menu"
 #define MENU_END	"EndMenu"
+#define DIREC_NOBOX	"NoBox"
 
 #define MENU_BUFF	255
 #define MAX_WORD	255
@@ -14,6 +15,7 @@ struct menu_items {
    int type;
    char *name;
    char *args;
+   char *prompt;
    struct menu_items *next, *prev;
 };
 
