@@ -10,6 +10,6 @@ void display_list(struct menu *menu_list);
 void write_str(char *s);
 void clear_scr();
 int readchar();
-void get_args(char *args, char *title);
+int get_args(char *args, char *title);
 
 #endif
